{% load i18n %}
<form action="{% url lfc_save_seo obj.id %}"
      method="POST">
    <table>
        {% include "lfc/manage/lfc_form.html" %}
    </table>
    <input class="ajax-save-button"
           type="submit"
           value="{% trans 'Save SEO' %}" />
</form>
