<html>
    <head>
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/yui/reset-min.css" />
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/css/lfc_manage.css" />
        <script type="text/javascript" src="{{ MEDIA_URL }}lfc/tiny_mce/jscripts/tiny_mce/tiny_mce_popup.js"></script>
        <script language="javascript" type="text/javascript" src="{{ MEDIA_URL }}lfc/js/fb_tinymce.js"></script>        
    </head>
    <body class="filebrowser">
        {% block content %}{% endblock %}
    </body>
</html>