{% extends "lfc/manage/base.html" %}
{% load i18n %}

{% block left_slot %}
    <div id="navigation">
        {{ navigation }}
    </div>
{% endblock %}

{% block content %}

    <div id="menu" 
         class="site-actions">
         {{ menu|safe }}
    </div>

    <div style="clear:both" id="manage-tabs">

        <ul>
            <li class="ui-tabs-nav-item"><a href="#data">{% trans content_type_name %}</a></li>
            <li class="ui-tabs-nav-item"><a href="#meta_data">{% trans 'Metadata' %}</a></li>
            <li class="ui-tabs-nav-item"><a href="#children">{% trans 'Children' %}</a></li>
            <li class="ui-tabs-nav-item"><a href="#images">{% trans 'Images' %}</a></li>
            <li class="ui-tabs-nav-item"><a href="#files">{% trans 'Files' %}</a></li>
            <li class="ui-tabs-nav-item"><a href="#portlets">{% trans 'Portlets' %}</a></li>
            <li class="ui-tabs-nav-item"><a href="#comments">{% trans 'Comments' %}</a></li>
            <li class="ui-tabs-nav-item"><a href="#seo">{% trans 'SEO' %}</a></li>
        </ul>

        <div id="data">
            {{ core_data|safe }}
        </div>
        <div id="meta_data">
            {{ meta_data|safe }}
        </div>
        <div id="seo">
            {{ seo_data|safe }}
        </div>
        <div id="images">
            {{ images }}
        </div>
        <div id="files">
            {{ files }}
        </div>
        <div id="portlets">
            {{ portlets }}
        </div>
        <div id="children">
            {{ children }}
        </div>
        <div id="comments">
            {{ comments }}
            </div>
        </div>
    </div>

    <script type="text/javascript">
        tinyMCE.execCommand('mceAddControl', true, 'id_text');
        tinyMCE.execCommand('mceAddControl', true, 'id_short_text');
    </script>

{% endblock %}