{% load i18n %}
{% load adminmedia %}

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
    <head>
        <title>{% block title %}{% endblock %}</title>
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/yui/reset-min.css" />
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/lightbox/css/jquery.lightbox-0.5.css" />
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/jquery/jquery-ui-themeroller/jquery-ui-themeroller.css" />
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/jquery/jquery.jgrowl.css" />
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/jquery/superfish/superfish.css" />
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/jquery/autocomplete/jquery.autocomplete.css" />
        <link rel="stylesheet" type="text/css" href="{{MEDIA_URL}}lfc/css/lfc_manage.css" />

        {# <script type="text/javascript" src="/admin/jsi18n/"></script> #}
        {# <script type="text/javascript" src="{% admin_media_prefix %}js/core.js"></script> #}
        {# <script type="text/javascript" src="{% admin_media_prefix %}js/calendar.js"></script> #}
        {# <script type="text/javascript" src="{% admin_media_prefix %}js/admin/DateTimeShortcuts.js"></script>         #}
        <script type="text/javascript" src="{% admin_media_prefix %}js/urlify.js"></script>

        <script type="text/javascript" src="{{MEDIA_URL}}lfc/tiny_mce/jscripts/tiny_mce/tiny_mce.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/jquery.min.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/jquery.tools.min.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/jquery.livequery.pack.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/jquery.form.pack.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/jquery.jgrowl_minimized.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/jquery.cookie.pack.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/superfish/superfish.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/jquery-ui-personalized-1.5.3.packed.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/jquery/autocomplete/jquery.autocomplete.pack.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/js/json2.js"></script>
        <script type="text/javascript" src="{{MEDIA_URL}}lfc/js/lfc_manage.js"></script>

        <script type="text/javascript" src="{{ MEDIA_URL }}lfc/swfupload/swfupload.js"></script>
        <script type="text/javascript" src="{{ MEDIA_URL }}lfc/swfupload/swfupload.queue.js"></script>
        <script type="text/javascript" src="{{ MEDIA_URL }}lfc/swfupload/fileprogress.js"></script>
        <script type="text/javascript" src="{{ MEDIA_URL }}lfc/swfupload/handlers.js"></script>

        <link rel="stylesheet" type="text/css" href="{{ MEDIA_URL }}lfc/swfupload/default.css" />

        {% block javascript %}{% endblock %}

    </head>
    <body class="{% block body_class %}{% endblock %}">
        <div class="lfc-header">
            <div class="logo">
                <a href="">
                    <img src="{{ MEDIA_URL }}lfc/img/logo.jpg"
                         alt="LFC"
                         title="LFC - Lightning Fast CMS"/>
                </a>
            </div>
            <div class="username">
                {% if user.is_authenticated %}
                    {% if user.last_name %}
                        <span>{{user.first_name}} {{user.last_name}}</span>
                    {% else %}
                        <span>{{ user.username }}</span>
                    {% endif %}
                    | <a class="logout"
                         href="{% url lfc_logout %}">{% trans 'Logout' %}</a>
                {% endif %}
            </div>

            <table class="top-menu"
                   width="100%">
                <tr>
                    <td>
                        <ul class="sf-menu"
                            width="100%">
                            <li>
                                <a href="{% url lfc_manage_portal %}">{% trans 'Content' %}</a>
                            </li>
                            <li>
                                <a>{% trans "Applications" %}</a>
                                <ul>
                                    <li>
                                        <a href="{% url lfc_content_types %}">{% trans 'Content Types' %}</a>
                                    </li>
                                    <li>
                                        <a href="{% url lfc_applications %}">{% trans 'Installer' %}</a>
                                    </li>
                                </ul>
                            </li>
                        </ul>
                    </td>
                </tr>
            </table>
        </div>

        <table class="main">
            <tr>
                {% block left-slot-wrapper %}
                    <td class="left-slot">
                        <div style="height:20px"></div>
                        {% block left_slot %}{% endblock %}
                    </td>
                {% endblock %}
                <td class="middle-slot">
                    {% block content %}{% endblock %}
                </td>
            </tr>
        </table>

        {% block footer %}
            <div class="footer">
                <p>{% trans 'Powered by' %} <a target="_blank" href="http://www.getlfs.com">LFC</a> &mdash; Lightning Fast CMS</p>
                <p>
                    LFC {% trans 'is a product of' %} <a target="_blank" href="http://www.iqpp.de">iqplusplus</a>
                    &mdash; &copy; 2009 <a target="_blank" href="http://www.iqpp.de">iqplusplus</a> &mdash; {% trans 'All rights reserved' %}
                </p>
                <p>{% trans 'Distributed under the' %} <a target="_blank" href="http://www.opensource.org/licenses/bsd-license.php">{% trans 'BSD-License' %}</a></p>
            </div>
        {% endblock %}

        <div class="overlay" id="overlay">
            <div class="content"></div>
        </div>

        <div class="modal" id="yesno"> 
            <p> 
                {% trans "Do you really want to delete this object?" %}
            </p> 

            <button> Yes </button> 
            <button> No </button> 
            
            <div style="display:none" id="delete-url">url</div>
        </div> 
        
        <span id="obj-id"
              data="{{ obj.id }}" />

    </body>
</html>